#
# spec file for package pcm
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           pcm
Version:        202502
Release:        1.1
Summary:        Intel Performance Counter Monitor
License:        BSD-3-Clause
URL:            https://github.com/intel/pcm
Source:         https://github.com/intel/pcm/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  make
ExclusiveArch:  %{ix86} x86_64

%description
Intel Performance Counter Monitor (PCM) is an application programming
interface (API) and a set of tools based on the API to monitor performance and
energy metrics of Intel Core, Xeon, Atom and Xeon Phi processors.

%prep
%setup -q

%build
%cmake -DCMAKE_BUILD_TYPE=CUSTOM -DCMAKE_INSTALL_PREFIX=%{_prefix} -DCMAKE_INSTALL_DOCDIR=%{_docdir}/pcm
%{!?cmake_build:%define cmake_build %{__cmake}}
%cmake_build

%install
%cmake_install
rm -rf %{buildroot}%{_docdir}/pcm/CUSTOM-COMPILE-OPTIONS.md
rm -rf %{buildroot}%{_docdir}/pcm/DOCKER_README.md
rm -rf %{buildroot}%{_docdir}/pcm/FREEBSD_HOWTO.txt
rm -rf %{buildroot}%{_docdir}/pcm/MAC_HOWTO.txt
rm -rf %{buildroot}%{_docdir}/pcm/WINDOWS_HOWTO.md
rm -rf %{buildroot}%{_docdir}/pcm/STARS.md
rm -rf %{buildroot}%{_docdir}/pcm/generate_summary_readme.md

%files
%license LICENSE
%doc doc/*HOWTO*
%dir %{_docdir}/pcm
%{_docdir}/pcm/ENVVAR_README.md
%{_docdir}/pcm/FAQ.md
%{_docdir}/pcm/LINUX_HOWTO.txt
%{_docdir}/pcm/PCM-EXPORTER.md
%{_docdir}/pcm/PCM-SENSOR-SERVER-README.md
%{_docdir}/pcm/PCM_RAW_README.md
%{_docdir}/pcm/CXL_README.md
%{_docdir}/pcm/LATENCY-OPTIMIZED-MODE.md
%{_docdir}/pcm/PCM_ACCEL_README.md
%{_docdir}/pcm/README.md
%{_docdir}/pcm/license.txt
%{_sbindir}/pcm
%{_sbindir}/pcm-core
%{_sbindir}/pcm-iio
%{_sbindir}/pcm-latency
%{_sbindir}/pcm-lspci
%{_sbindir}/pcm-memory
%{_sbindir}/pcm-msr
%{_sbindir}/pcm-tpmi
%{_sbindir}/pcm-mmio
%{_sbindir}/pcm-numa
%{_sbindir}/pcm-accel
%{_sbindir}/pcm-pcicfg
%{_sbindir}/pcm-pcie
%{_sbindir}/pcm-power
%{_sbindir}/pcm-sensor
%{_sbindir}/pcm-tsx
%{_bindir}/pcm-client
%{_sbindir}/pcm-bw-histogram
%{_sbindir}/pcm-daemon
%{_sbindir}/pcm-sensor-server
%{_sbindir}/pcm-raw
%dir %{_datadir}/pcm
%{_datadir}/pcm/opCode-6-106.txt
%{_datadir}/pcm/opCode-6-85.txt
%{_datadir}/pcm/opCode-6-134.txt
%{_datadir}/pcm/opCode-6-143.txt
%{_datadir}/pcm/opCode-6-143-accel.txt
%{_datadir}/pcm/opCode-6-173.txt
%{_datadir}/pcm/opCode-6-175.txt
%{_datadir}/pcm/opCode-6-207.txt
%{_datadir}/pcm/opCode-6-182.txt
%{_datadir}/pcm/opCode-6-174.txt
%{_datadir}/pcm/PMURegisterDeclarations

%changelog
* Sat Mar  1 2025 Roman Dementiev <roman.dementiev@intel.com>
- Update to version 202502
  * Xeon 6 SoC (GNR-D) support
  * add Grand Ridge (GRR) support
  * pcm-power: support tpmi perf limit reason telemetry for GNR and SRF
  * add ARL (Arrow Lake) support
  * add basic support for Elkhart Lake and Jasper Lake CPUs
  * pcm-raw: implement support for tpmi registers
  * pcm-raw: add PMT XML lookup
  * support SYS energy API
  * pcm-sensor-server: change protocol to IPv6, this should work fine on Linux dual stack systems
  * introduce socketUniqueCoreID to again create a unique Core ID for the JSON and Prometheus output
  * pcm-numa: enable support for GNR
  * pcm-tsx: support GNR
  * introduce and use PCM_DEBUG_LEVEL env variable to print debug messages
  * support pcm-iio inside docker container
  * pcm: make --color default on UNIX-like OSes
  * pcm: introduce --no-color option
  * pcm: add csv output for system power
  * make c-state output more compact
  * use a relative path in LINUX_SYSTEMD_UNITDIR (@hexchain)
  * perf optimization for accumulating socket CStateResidency
  * create unique core ids and fix threads_per_core
  * pcm-tpmi: fix multiple bugs
  * disable libasan by default due to bugs in libasan
* Fri Sep 27 2024 Roman Dementiev <roman.dementiev@intel.com>
- Update to version 202409:
  * Intel Xeon 6 processors with P-cores (Granite Rapids) support
  * Lunar Lake support
  * support pcm-power on Sierra Forest processors
  * grafana: add core and uncore frequencies metrics
  * grafana: add TMA and local/remote access ratio metrics
  * pcm-tpmi: add -i instances option
  * pcm-sensor-server: enable compilation with SSL
  * pcm-sensor-server: addition of a fuzzing client and subsequent rewrite of parts of the network communication and SSL detection
  * pcm-sensor-server: stop using deprecated SSL functions
  * pcm-memory: replace NODE with SKT to avoid confusion with NUMA NODEs
  * avoid using the hard-coded /usr/share/pcm/ path
  * grafana: change the refresh period to 1s
  * grafana: show energy charts after freq charts
  * pcm-raw: make ICX PMURegisterDeclarations available on older steppings
  * add -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer and other hardening
  * set pointers to nullptr after delete or free
  * add PCM_ENFORCE_MBM option (env variable)
  * erase unneeded environment variables
  * handle TPMI initilization for systems without access to MCFG tables e.g. docker/VM
  * fix ssl accept issues
  * fix public github issue #810
  * fix double free
  * pcm-raw: really use the alt_path if it exists (a bug fix)
  * link 1 does not have own speed register only on QPI
  * grafana: don't show unsupported metrics in prometheus
  * disable unsupported freq metrics for prometheus
  * fix locking in AcceleratorCounterState::getInstance()
  * fix a crash due to uninitialized array
  * avoid pre-mature PCM init triggered by global counter state init
  * fix a heap-buffer-overflow and a memory leak and throw exception with verbose reason
  * do not include shared library code into pcm-core executable
  * address issue #758 SPR UPI discovery table is broken on SPR MCC
* Thu May 23 2024 Roman Dementiev <roman.dementiev@intel.com>
- Update to version 202405:
  * Xeon 6E Processor Support: Added support for Xeon 6E processor (Sierra Forest/SRF).
  * pcm-iio: Enabled pcm-iio for Sierra Forest (SRF) processors.
  * Intel QAT Support: Added support for QAT Linux in-tree driver addressing issue#547.
  * Meteor Lake Support: Added support for Meteor Lake processors.
  * Intel PMT raw counter support in pcm-raw: Added support for Intel Platform Monitoring Technology Telemetry (Intel PMT) raw counters.
  * Client CPU Energy Metrics: Support for client CPU energy metrics in Grafana.
  * Colorful Display: Added --color option for colorful display in the command-line interface.
  * CPU Support: Support for more CPUs added for localMemoryRequestRatioMetric.
  * Precise UPI Speed Detection: Improved UPI speed detection on SPR using UPI_SPEED_REGISTER.
  * Metric Version 2: Made metric version 2 the default setting.
  * Dashboard Graph: Replaced Graph with Timeseries for better visualization in the dashboard.
  * Incorrect PMON IDs: Fixed incorrect PMON IDs for HCx stacks.
  * Ubox PMU Declarations: Added declarations for ubox PMU.
  * Crash on BDX: Fixed a crash on BDX when trying to program IRP or IIO PMU.
  * Less Useful Metrics: Disabled less useful metrics to streamline performance monitoring metric display.
* Sun Mar 17 2024 Roman Dementiev <roman.dementiev@intel.com>
- Update to version 202403:
  * pcm: implement alternative metrics option -m (UTIL=C0 residency for cores, CFREQ=core frequency in GHz) and make it default
  * hardened binaries with "-Wl,-z,now" option on Linux
  * pcm-raw: fall-back to older stepping PMURegisterDeclarations if available
  * Detect UPI LL PMUs on SPR/EMR through uncore PMU discovery and detect IMC PMUs on SPR/EMR through uncore PMU discovery
  * Fixed parameter parsing in pcm-sensor-server
  * Added Emerald Rapids processor support
  * Added support for TMA Level 2 metrics on SPR+
  * Added support of PP0 and PP1 energy metrics
  * Added -c option (corelist) to pcm-numa and pcm-msr utilites
  * pcm-msr new options added: iterate with seconds between each iteration and write results of each iteration to file
  * Removed hardcoded value for max supported sockets in pcm-iio tool
  * Rely on CPUID leaf 0x1F topology info when available
* Sun Mar 10 2024 Roman Dementiev <roman.dementiev@intel.com>
- Fixed Tumbleweed builds
* Mon Dec 11 2023 Roman Dementiev <roman.dementiev@intel.com>
- Update to version 202311:
  * Support for Sapphire Rapids accelerators in pcm-grafana dashboard.
  * Added support of Sapphire Rapids MCC CPUs in pcm-iio tool.
  * Added support for M3UPI PMU for Sapphire Rapids.
  * Added new tool to access TPMI registers: pcm-tpmi
  * Added support for mmio register reads in pcm-raw tool
  * pcm-raw now supports ha pmu and added invert,anythread,nc,isoc,opc and state emon event modifiers
  * New script for filtering data in CSV
  * Added bit operations for pcm register tools: pcm-msr, pcm-pcicfg, pcm-mmio
  * pcm-raw: Add PCU PMU declaration for BDX/SKX/CLX/CPX and document pcicfg register events
  * pcm-raw: remove the max number of event restrictions for register events
  * Fixed deadlock in processDVSEC
  * Fixed race condition in isHWTMAL1Supported
  * Fixed a clang scan warning
  * Fixed the docker name for Grafana in start.sh
  * Fixed an issue in getMaxNumOfCBoxes to allow the fall-back perf API method to be called
  * Fixed an issue with pcicfg reg syntax documentation
  * Fixed an issue in pcm-accel to avoid confusion when overflow happens
  * Added exception handling in utils.cpp:get_cpu_bus()
  * Fix pcm for PCU and MDF: IO read size is data size
  * Added PCM_NO_MAIN_EXCEPTION_HANDLER variable
* Sun Jul 16 2023 Dirk Müller <dmueller@suse.com>
- update to 202307:
  * pcm-memory and grafana dashboard: support CXL bandwidth
    monitoring on Sapphire Rapids
  * pcm-raw: support collection for MSR and PCICFG (CSR)
    registers in csv format
  * pcm-mmio: support dumps for memory regions
  * pcm-raw: additional CPU model/steppings supported (CPX, SPR)
  * pcm-pcicfg: support PCICFG register lookup/search by device
    ID
  * documentation updates (how to run under non-root user, CXL
    monitoring, pcm-accel IAA, DSA, QAT, pcm-raw register
    monitoring)
  * bug fixes
* Thu Apr 20 2023 Jan Engelhardt <jengelh@inai.de>
- Trim R/TM signs as per
  https://en.opensuse.org/openSUSE:Package_description_guidelines
* Tue Feb 21 2023 Roman Dementiev <roman.dementiev@intel.com>
- Update to version 202302:
  * pcm-accel: support monitoring of Intel QuickAssist Technology (QAT) performance metrics
  * grafana: support grafana dashboards with multiple hosts (with host selector) and fix UPI charts
  * grafana: added dram pmem bandwidth and their ratio to grafana charts
  * added python script to automate the generation of summary reports from pcm csv
  * added backtrace info with signal SEGV for better debugability
  * pcm-pcie: fix issues with delay parameter
  * pcm-raw: validate counter event restrictions
  * pcm-raw: initial support of hybrid cpus
  * added LLCRDMISSLAT metric support for SPR
  * added support for Gemini Lake
  * added support memory bandwidth metrics for more ADL&TGL CPU models
  * added systemd unit for Linux systems
  * pcm-sensor-server: enhanced error handling in close, setSocket and sync calls
  * avoid using errata events on older processors
  * pcm-sensor-server: implement -force-rtm-abort-mode option
* Fri Dec 23 2022 Roman Dementiev <roman.dementiev@intel.com>
- Update to version 202212:
  * pcm-memory: add SPR HBM support
  * support multiple hosts for Grafana dashboard with prometheus
  * fixes for pcm-iio/pcm-accel
* Thu Nov 24 2022 Roman Dementiev <roman.dementiev@intel.com>
  updated to the new upstream repository location and the name
- Update to version 202211:
  * added Sapphire Rapids processor support
  * added new pcm-accel utility to monitor Sapphire Rapids accelerator performance
  * added --version option to all pcm tools
  * pcm: new "enforce flush output" option
  * pcm-raw: support ocr_msr_val and tid modifiers
  * fixed default value for CHA filter1 on CLX and SKX
  * pcm-sensor-server: allow build on FreeBSD
  * pcm-raw: adopt new JSON event file format, new URLs for perfmon event lists
* Mon Oct 31 2022 Coly Li <colyli@suse.de>
- Synchronize pcm package from openSUSE to SLES15-SP* supported
  produces (jsc#PED-395, jsc#PED-1004)
- Update to version 202210:
  * Add simdjson submodule and move simdjson lib to version 2.0.4
  * Add  SNR register definitions
  * Fix some build related issues
  * Improvement on printing error messages
  * Fix sporadic crashes
  * Fix top-down events on some Linux kernels
  * Remove 32 bit code from DriverInterface
  * Remove public header file and remove header files from installation
  * Add IOUserClient class to CMake builds, and add fields in kernel
    topology structure to match userland structure
  * Remove of use of volatile and make memory allocation only for the
    lifetime of a function that needs it
  * Move DriverInterface code into MSRAccessor
  * Expand custom counter memory for PCM-Service
  * Removing of potentially existed files (symlinks) before writing
  * pcm-memory: option to enforce output flush
  * Implement RPL support
  * Introduce Raptor Lake IDs
* Tue Jul 26 2022 Roman Dementiev <roman.dementiev@intel.com>
- Update to version 202207:
  * pcm-raw: add json output to pcm-raw
  * pcm-memory: fix csv output inconsistency for channels without traffic
  * fix automatic version generation on checkout
  * use GNUInstallDirs for install paths
  * pcm-iio: optionally display root port pci device id
  * automatically increase limit on open files on Linux
  * pcm-daemon: add 'memory mode hit approximation' metric + client sample app fixes
  * pcm-daemon: document all pcm-daemon metrics in the common.h header
  * add CPU model number in processor information list
  * correct hardcoded QPI strings and change to UPI when applicable
  * pcm-iio: add missing header item
  * pcm-raw: fix "EDP" format prints for offlined cores
  * PCM_KEEP_NMI_WATCHDOG=1 env variable to keep NMI watchdog running
  * support pcm-iio on ICX-D
  * support additional Alderlake cpu model
  * document -pid option in pcm-numa and pcm-tsx
* Wed May  4 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 202203:
  * Add experimental pcm csv data plot and background collection scripts
  * Print 4 digits for MPI metrics
  * Uncore linux perf event robustness enhancements
  * pcm-raw: additional overhead reduction for multi-group collection
  * general overhead reduction (skip restoring thread affinity when not required)
  * pcm-numa, pcm-tsx: add -pid option
  * Fix compilation of examples on old gcc
  * Fix: restore affinity for caller process
  * Fixed race condition in resctrl (when not available)
* Fri Jan 28 2022 Roman Dementiev <roman.dementiev@intel.com>
- Update to 202201 upstream version:
  * use cmake to build the project
  * reduce pcm overhead
  * pcm-raw: add -r option (PMU reset)
  * pcm-raw: add a sample separator option
  * freeze/unfreeze all core PMU counters during the read operation
  * change ulimit recommendations
  * various performance and bug fixes
* Sun Dec 26 2021 Roman Dementiev <roman.dementiev@intel.com>
- Update to 202112:
  * pcm: expose DRAM_GT_REQUESTS and DRAM_IA_REQUESTS bandwdith metrics
  * pcm: added client IO and GT bandwidth metrics to CSV output
  * pcm-memory: added -u option (clear screen before stat update)
  * pcm-memory: added -s option (silent mode)
  * pcm-memory: add csv print support for DRAM rank monitoring
  * pcm-memory: disable pmem output when rank monitoring is enabled
  * pcm-power: support for <1 sec delay
  * pcm-raw: added -i option (limits the number of iterations/samples)
  * pcm-raw: add support of IRP events
  * pcm-raw: add thousand separator and tab separator options
  * pcm-pcie: support 8 socket platforms
  * pcm-power: add core power license statistics
  * various small fixes and enhancements
* Sat Oct 30 2021 Roman Dementiev <roman.dementiev@intel.com>
- Update to 202110:
  * support ADL (Alder Lake) in pcm tool
  * display average uncore frequency in pcm.x
  * allow verbose CPU topology printing with PCM_PRINT_TOPOLOGY environment variables
  * pcm-raw: support event group multiplexing
  * pcm-iio: support csv output
  * developed a workaround to make PCM work in VMware guest
  * various bug fixes
* Sun Jul 25 2021 Roman Dementiev <roman.dementiev@intel.com>
- Update to 202107:
  * support systems with > 1024 logical cores
  * support Rocket Lake
  * pcm-pcie: fix HIT metrics calculation on Broadwell/Haswell server platforms
  * pcm: add several additional columns to the socket and core sections in csv output
  * pcm-iio: fix multiplier value for outbound events on Snowridge and Icelake server platforms
  * implement workaround for Linux watchdog not clearing its event programming
  * move Icelake top-down events to a separate group to fix counting through Linux perf API
  * added pcm-mmio utility to rpm
* Tue May 25 2021 Roman Dementiev <roman.dementiev@intel.com>
- Update to 202105:
  * support Intel Atom Processor P5900 Series (previously codenamed SnowRidge)
  * address Linux warnings
* Tue May  4 2021 Roman Dementiev <roman.dementiev@intel.com>
- Update to 202104:
  * Add Icelake server support
* Sat Feb 20 2021 Roman Dementiev <roman.dementiev@intel.com>
- Update to 202101:
  * Add Comet Lake support
  * Add Tiger Lake support
  * Add support for additional Icelake cpu model
  * Support Linux resctrl driver for RDT Metrics (see ENVVAR_README.md)
  * Improve robustness in handling rare core event overflows
  * A few fixes for c_example
  * Support using Linux perf API for core PMU for systems with offlined cores
  * Add -i parameter to more tools
  * support select metrics in virtual machines with vPMU support (e.g. AWS virtualized instances with arch_perfmon flag). Screenshot of grafana dashboard with PCM data from a c5.9xlarge virtualized AWS instance
  * pcm-iio: fix VT-d events on SKX
  * pcm-memory: make -pmm/-pmem the default option on systems with PMM/PMem support
  * pcm-tsx: update events for ICL and SKL, allow collection of up to 8 events
  * pcm-raw: support fixed PMU counters
  * fix UBOX MSR addresses for Jaketown/Ivytown
  * support Icelake client CPUs
  * new pcm-raw utility: to program arbitrary core and uncore events by specifying raw register event ID encoding
  * pcm-memory: support -all option to show channels event if they do not have any traffic (inactive memory channels)
  * pcm-memory: csv output for Near Memory hit rate (in PMem Memory Mode)
  * pcm-memory: show memory channels with PMM but w/o DRAM DIMMs
  * unfreeze counters using global uncore counter control register during uncore PMU initialization (some other tools freeze using global control before exit)
* Thu Aug 27 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 202007:
  * no upstream changelog
* Wed Apr 29 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Build only for %%ix86 x86_64 as it targets Intel CPU only
* Mon Apr 29 2019 Tomáš Chvátal <tchvatal@suse.com>
- Remove the TM/etc. blurbs
* Thu Apr 18 2019 Tomáš Chvátal <tchvatal@suse.com>
- Initial commit, jsc#6867
